#include "oled_switch_hw.h"
#include "paint_bitmap.h"

#define IMG_SIZE      6144      //For still images this size is good, because display is only this size.
#define BIG_IMG_SIZE  12288     //For scrolling, you must use bigger image, because of firmware on module,
                                //( Module attempts to scroll 96x64 display despite memory allocated being smaller )
//GPIOs
sbit OLED_SWITCH_RST         at LATC1_bit;
sbit OLED_SWITCH_RST_DIR     at TRISC1_bit;
sbit OLED_SWITCH_CS          at LATC2_bit;
sbit OLED_SWITCH_CS_DIR      at TRISC2_bit;
sbit OLED_SWITCH_CMD         at LATD0_bit;
sbit OLED_SWITCH_CMD_DIR     at TRISD0_bit;

//Function Prototypes
void system_setup( buffer_size_t size );

void main()
{
    //Local Declarations
    scroll_t scroll;               //Used for scroll settings

    scroll.col_horiz_shift = 0x01; //Shift left to right
    scroll.row_offset      = 0;    //No offset of rows
    scroll.row_horiz_shift = 64;   //64: BIG IMAGE, 47:SMALL ( SMALL doesn't work well, because of firmware on click side )
    scroll.row_vert_shift  = 5;    //No vertical shifting
    scroll.interval        = 0;    //1: 10 frames between each shift

    //Setup
    system_setup( BIG ); //Provide size of allocated space for images ( 64x48 or 96x64 )

    //oled_switch_deactivate_scrolling();                                   //Scrolling must be absolutely deactivated first
    //oled_switch_scrolling_setup( scroll );                                //Next, setup scroll settings
    oled_switch_draw_565_img( bird_bmp, BIG_IMG_SIZE );   //Draw the image to scroll
    //oled_switch_activate_scrolling();                                     //Activate scrolling on screen

    while( 1 )//Forever
    {

    }
}

void system_setup( buffer_size_t size )
{
    OLED_SWITCH_RST_DIR = 0;    //RST
    OLED_SWITCH_CS_DIR  = 0;    //CS
    OLED_SWITCH_CMD_DIR = 0;    //CMD or CD  ( Command / Data )

    //UART
    UART2_Init( 9600 );
    Delay_ms(300);
    UART2_Write_Text( "UART Initialized\r\n" );

    // SPI
    SPI3_Init_Advanced( _SPI_MASTER, _SPI_8_BIT, 16, _SPI_SS_DISABLE,
                        _SPI_DATA_SAMPLE_MIDDLE, _SPI_CLK_IDLE_HIGH,
                        _SPI_ACTIVE_2_IDLE );
    Delay_ms(300);
    UART2_Write_Text( "SPI Initialized\r\n" );

    //Initialize OLED Switch click
    oled_switch_init( size );
    Delay_ms( 300 );
    UART2_Write_Text( "OLED Switch click Initialized\r\n" );

}